@@ -265,6 +265,7 @@ class DataSource(LinkedLastModifiedItem, Graphable, DeterministicHashDictMixin,
                     run_pipeline = True
                 elif lm == pipeline_lm and lm != source_lm:
                     run_pipeline = True
+
                 if pipeline_lm is None:
                     reason = LoadFromPipelineReason.NO_LAST_MODIFIED_IN_PIPELINE
                 elif source_lm is None:
@@ -621,6 +622,8 @@ class DataSource(LinkedLastModifiedItem, Graphable, DeterministicHashDictMixin,
 
     def _duplicate_column_for_calculation(self, df: pd.DataFrame, orig_var: Variable, new_var: Variable,
                                           pre_rename: bool = True):
+        logger.debug(f'Duplicating column for calculation in source {self.name} for '
+                     f'orig variable {orig_var}, new variable {new_var}')
         # should get column which already has data for this variable
         existing_col = self.col_for(orig_var)
 
